# Changelog

## [0.2.0](https://github.com/miettal/jupyterhub-samlauthenticator-kai/compare/v0.1.0...v0.2.0) (2023-11-18)


### Features

* add publish ci ([0b5ddc0](https://github.com/miettal/jupyterhub-samlauthenticator-kai/commit/0b5ddc04c417caf0971faf29288901cafdac4259))
* change setup.py to pyproject.toml ([cd9c547](https://github.com/miettal/jupyterhub-samlauthenticator-kai/commit/cd9c547f798b3dd86ac1ced7a49f3d43ff557662))

## [0.1.0](https://github.com/miettal/jupyterhub-samlauthenticator/compare/v0.0.10...v0.1.0) (2023-11-18)


### Features

* support jupyterhub&lt;=4.0 ([30e2544](https://github.com/miettal/jupyterhub-samlauthenticator/commit/30e25446ef2cf51afdaefc5dba5e5ed3cfe26b48))
* switch to saml2 ([c15b569](https://github.com/miettal/jupyterhub-samlauthenticator/commit/c15b569d431239b0d23bb1b865bed22d15516f99))


### Bug Fixes

* add pysaml2 dependency and deop sp_metadata endpoint ([4cc49eb](https://github.com/miettal/jupyterhub-samlauthenticator/commit/4cc49eb8daab080a14fd0024e8ffb097488c66ad))
* add release-please ([80fa4c4](https://github.com/miettal/jupyterhub-samlauthenticator/commit/80fa4c46e8d76113c716f72332b0ffb2d82a110d))
* drop sp-metadata method ([37d633f](https://github.com/miettal/jupyterhub-samlauthenticator/commit/37d633f3eb160646d685c36e70c7ff34e93b9553))
* fix lint ([1c1fd90](https://github.com/miettal/jupyterhub-samlauthenticator/commit/1c1fd90dbf7b324aa3ab2acbac04eb614968d324))
* fix setup.py ([c688e4a](https://github.com/miettal/jupyterhub-samlauthenticator/commit/c688e4afeda96e7b4bb7d5d078b73bd77fe20b79))
* replace test code from original to new one ([dc71042](https://github.com/miettal/jupyterhub-samlauthenticator/commit/dc71042fa51f16e6f206d46cd7ee3803336ed61e))
